@@ -52,7 +52,7 @@ void tangle_action_execute_full(TangleAction* action, GObject* source, const gch
 	}
 }
 
-void tangle_action_execute_full_list(TangleAction* action, GObject* source, const gchar* trigger, const gchar* first_property_name, ...) {
+void tangle_action_execute_full_list(TangleAction* action, GObject* source, const gchar* trigger, ...) {
 	va_list properties_list;
 	
 	va_start(properties_list, trigger);
