@@ -290,6 +290,13 @@ static void tangle_binding_finalize(GObject* object) {
 	TangleBinding* binding;
 	
 	binding = TANGLE_BINDING(object);
+
+	if (binding->priv->objects[0]) {
+		g_object_weak_unref(binding->priv->objects[0], on_destroy_notify, binding);
+	}
+	if (binding->priv->objects[1]) {
+		g_object_weak_unref(binding->priv->objects[1], on_destroy_notify, binding);
+	}
 	
 	disconnect_notify_signals(binding);
 	g_free(binding->priv->properties[0]);
