@@ -20,7 +20,7 @@ static void clutter_scriptable_iface_init(ClutterScriptableIface* iface);
  * contain an array of ids of #TangleButton actors.
  */
 
-G_DEFINE_TYPE_WITH_CODE(TangleButtonGroup, tangle_button_group, G_TYPE_OBJECT,
+G_DEFINE_TYPE_WITH_CODE(TangleButtonGroup, tangle_button_group, TANGLE_TYPE_OBJECT,
                         G_IMPLEMENT_INTERFACE(CLUTTER_TYPE_SCRIPTABLE, clutter_scriptable_iface_init););
 
 enum {
@@ -264,7 +264,6 @@ static void tangle_button_group_set_custom_property(ClutterScriptable* scriptabl
 		slist = (GSList*)g_value_get_pointer(value);
 		for (slist_item = slist; slist_item; slist_item = slist_item->next) {
 			tangle_button_group_add_button(button_group, TANGLE_BUTTON(slist_item->data));
-			g_free(slist_item->data);
 		}
 		g_slist_free(slist);	
 	} else if (parent_scriptable_iface->set_custom_property) {
