@@ -8,6 +8,7 @@
  */
 
 #include "tangle-private.h"
+#include "tangle-actor.h"
 
 typedef struct _TemplateParameter {
 	gchar* name;
@@ -53,26 +54,34 @@ gboolean _tangle_scriptable_parse_custom_node(ClutterScriptable* scriptable, Clu
 		}
 	} else if (!strcmp(name, "template")) {
 		*template_found_pointer = TRUE;
-	} else if ((param_spec = g_object_class_find_property(G_OBJECT_CLASS(type_class), name)) &&
-	           G_IS_PARAM_SPEC_OBJECT(param_spec) &&
-		   !g_type_is_a(G_PARAM_SPEC_VALUE_TYPE(param_spec), TANGLE_TYPE_TEMPLATE) &&
-	           (s = json_node_get_string(node)) &&
-		   (object = clutter_script_get_object(script, s)) &&
-		   TANGLE_IS_TEMPLATE(object)) {
-		if (!g_type_is_a(tangle_template_get_object_type(TANGLE_TEMPLATE(object)), G_PARAM_SPEC_VALUE_TYPE(param_spec))) {
-			g_warning("The type of the template '%s' does not match to the property '%s', skipped.", s, name);
-		} else {
-			id = g_strconcat(clutter_get_script_id(G_OBJECT(scriptable)), "$", name, NULL);
-			if (!(object = tangle_template_create_object_with_id(TANGLE_TEMPLATE(object), id))) {
-				g_warning("Could not instantiate the template '%s' for the property '%s', skipped.", s, name);
+	} else if ((param_spec = g_object_class_find_property(G_OBJECT_CLASS(type_class), name))) {
+		if (G_PARAM_SPEC_VALUE_TYPE(param_spec) == TANGLE_TYPE_SPACING) {
+			TangleSpacing spacing;
+	
+			if ((retvalue = tangle_spacing_parse_from_json(&spacing, node))) {
+				g_value_init(value, TANGLE_TYPE_SPACING);
+				g_value_set_boxed(value, &spacing);
+			}
+		} else if (G_IS_PARAM_SPEC_OBJECT(param_spec) &&
+			   !g_type_is_a(G_PARAM_SPEC_VALUE_TYPE(param_spec), TANGLE_TYPE_TEMPLATE) &&
+			   (s = json_node_get_string(node)) &&
+			   (object = clutter_script_get_object(script, s)) &&
+			   TANGLE_IS_TEMPLATE(object)) {
+			if (!g_type_is_a(tangle_template_get_object_type(TANGLE_TEMPLATE(object)), G_PARAM_SPEC_VALUE_TYPE(param_spec))) {
+				g_warning("The type of the template '%s' does not match to the property '%s', skipped.", s, name);
 			} else {
-				g_value_init(value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
-				g_value_set_object(value, object);
+				id = g_strconcat(clutter_get_script_id(G_OBJECT(scriptable)), "$", name, NULL);
+				if (!(object = tangle_template_create_object_with_id(TANGLE_TEMPLATE(object), id))) {
+					g_warning("Could not instantiate the template '%s' for the property '%s', skipped.", s, name);
+				} else {
+					g_value_init(value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
+					g_value_set_object(value, object);
 
-				retvalue = TRUE;
+					retvalue = TRUE;
 
+				}
+				g_free(id);
 			}
-			g_free(id);
 		}
 	}
 
